==> legacylisten-0.1.0.crate: legacylisten-0.1.0/src/l10n/english.rs <==
pub static ENGLISH_L10N_STR: &str = "
-name = legacylisten
total-playing-likelihood = total playing likelihood: { $val }
help-notice = Press `?` to show a help message
unknown-command-char = unknown command: { $char }
unknown-command-byte = unknown command: { $byte }
in-signal-handler = In signal handler with signal { $sig }
signal-handler-unreachable = All possible signals are already covered!
mpris-handler-error = Error with MPRIS: { $err }
memory-tight = Memory is very tight, stopping …
new-song-found = Found a new song: { $filename }
no-songs = No playable songs
print-playing-song = Printing information about the playing song
title = Title
album = Album
artist = Artist
album-artist = Album artist
year = Year
genre = Genre
date-recorded = Date recorded
date-released = Date released
disc = Disc #
discs-total = Disc total #
track = Track #
tracks-total = Tracks total #
duration = Duration
lyrics = Lyrics
sync-lyrics = Synchronized lyrics
comment = Comment
num-pictures = Pictures #
ext-links = ————Extended Links————
ext-texts = ————Extended Texts————
metadata-unsupported = Metadata is not supported for this song
print-info-unreachable = this shouldn't be reached
max-likelihood-reached = Maximal playing likelihood already reached
likelihood-increased = playing likelihood increased to { $likelihood }
song-already-never = Song will already never be played again
likelihood-decreased = playing likelihood decreased to { $likelihood }
song-never = song won't be played ever again
stopping-program = stopping {-name}
already-paused = already paused
pausing = pausing
resuming = resuming
already-running = already running
skipping-song = skipping song
making-louder = making louder to { $loud }%
making-quieter = making quieter to { $loud }%
loud-zero = loudness below zero requested; using 0%
duration-known = { $pos }s of { $len }s
duration-unknown = { $pos }s of {\"{unknown}\"}
already-quitting = Already quitting after current song
quitting-after = Quitting after current song
already-pausing = Already pausing after current song
pausing-after = Pausing after current song
opening-picture = Opening picture
nothing-playing-yet = No song playing yet
cant-open-picture = Can't open picture
not-repeating-already = Not repeating already
stopping-repeating = Stopping repeating
already-repeating-once = Already repeating once
repeating-once = Repeating once
already-repeating-forever = Already repeating forever
repeating-forever = Repeating forever
already-playing-first = Already playing first song in the playlist
increase-likelihood = Increase likelihood of current song
decrease-likelihood = Decrease likelihood of current song
quit = Quit {-name}
pause = Pause playing
resume = Resume playing
skip = Skip song
increase-volume = Increase volume of current song
decrease-volume = Decrease volume of current song
show-duration = Show Duration
switch-play-pause = Switch between playing and pausing
quit-after-song = Quit after current song
pause-after-song = Pause after current song
show-info = Show information about current song
open-cover = Open cover image in an external program
disable-repeat = Disable repeating of current song
repeat-once = Repeat current song once
repeat-forever = Repeat current song forever
skip-to-previous = Skip to previous song
help-header = Press the corresponding letter of the command that you want to execute:
command-reading-problem = problem with reading commands; ending …
reading-song-problem = Problem reading song { $path }: { $err }
choosing-new-song = Choosing new song
playing-song = Playing song: { $song }
playing-song-unknown = Playing song with strange name
song-likelihood = Song likelihood is { $likelihood }
signal-paused = Paused by signal
requested-pause = pausing as requested previously
saving-state-err = Error with saving state
state-saved = State successfully saved
unknown-title = Unknown title
unknown-artist = Unknown artist
previous = Will play previous song.
controller-out = Controller channel out of scope; this is a bug, please report it
";
pub static ENGLISH_L10N_LANG_ID: &str = "en-US";

==> legacylisten-0.1.1.crate: legacylisten-0.1.1/src/l10n/english.rs <==
pub static ENGLISH_L10N_STR: &str = "
-name = legacylisten
total-playing-likelihood = total playing likelihood: { $val }
help-notice = Press `?` to show a help message
unknown-command-char = unknown command: { $char }
unknown-command-byte = unknown command: { $byte }
in-signal-handler = In signal handler with signal { $sig }
signal-handler-unreachable = All possible signals are already covered!
mpris-handler-error = Error with MPRIS: { $err }
memory-tight = Memory is very tight, stopping …
new-song-found = Found a new song: { $filename }
no-songs = No playable songs
print-playing-song = Printing information about the playing song
title = Title
album = Album
artist = Artist
album-artist = Album artist
year = Year
genre = Genre
date-recorded = Date recorded
date-released = Date released
disc = Disc #
discs-total = Disc total #
track = Track #
tracks-total = Tracks total #
duration = Duration
lyrics = Lyrics
sync-lyrics = Synchronized lyrics
comment = Comment
num-pictures = Pictures #
ext-links = ————Extended Links————
ext-texts = ————Extended Texts————
metadata-unsupported = Metadata is not supported for this song
print-info-unreachable = this shouldn't be reached
max-likelihood-reached = Maximal playing likelihood already reached
likelihood-increased = playing likelihood increased to { $likelihood }
song-already-never = Song will already never be played again
likelihood-decreased = playing likelihood decreased to { $likelihood }
song-never = song won't be played ever again
stopping-program = stopping {-name}
already-paused = already paused
pausing = pausing
resuming = resuming
already-running = already running
skipping-song = skipping song
making-louder = making louder to { $loud }%
making-quieter = making quieter to { $loud }%
loud-zero = loudness below zero requested; using 0%
duration-known = { $pos }s of { $len }s
duration-unknown = { $pos }s of {\"{unknown}\"}
already-quitting = Already quitting after current song
quitting-after = Quitting after current song
already-pausing = Already pausing after current song
pausing-after = Pausing after current song
opening-picture = Opening picture
nothing-playing-yet = No song playing yet
cant-open-picture = Can't open picture
not-repeating-already = Not repeating already
stopping-repeating = Stopping repeating
already-repeating-once = Already repeating once
repeating-once = Repeating once
already-repeating-forever = Already repeating forever
repeating-forever = Repeating forever
already-playing-first = Already playing first song in the playlist
increase-likelihood = Increase likelihood of current song
decrease-likelihood = Decrease likelihood of current song
quit = Quit {-name}
pause = Pause playing
resume = Resume playing
skip = Skip song
increase-volume = Increase volume of current song
decrease-volume = Decrease volume of current song
show-duration = Show Duration
switch-play-pause = Switch between playing and pausing
quit-after-song = Quit after current song
pause-after-song = Pause after current song
show-info = Show information about current song
open-cover = Open cover image in an external program
disable-repeat = Disable repeating of current song
repeat-once = Repeat current song once
repeat-forever = Repeat current song forever
skip-to-previous = Skip to previous song
help-header = Press the corresponding letter of the command that you want to execute:
command-reading-problem = problem with reading commands; ending …
reading-song-problem = Problem reading song { $path }: { $err }
choosing-new-song = Choosing new song
playing-song = Playing song: { $song }
playing-song-unknown = Playing song with strange name
song-likelihood = Song likelihood is { $likelihood }
signal-paused = Paused by signal
requested-pause = pausing as requested previously
saving-state-err = Error with saving state
state-saved = State successfully saved
unknown-title = Unknown title
unknown-artist = Unknown artist
previous = Will play previous song.
controller-out = Controller channel out of scope; this is a bug, please report it
too-many-tries = Too many unsuccessful tries to read a song were made; probably all songs are unplayable; ending …
";
pub static ENGLISH_L10N_LANG_ID: &str = "en-US";
